Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2853)

Unified Diff: chrome/browser/prefs/pref_service_builder.h

Issue 11741003: Remove PrefServiceSimple, replacing it with PrefService and PrefRegistrySimple. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Switch to desired interfaces. Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/prefs/pref_service_builder.h
diff --git a/chrome/browser/prefs/pref_service_builder.h b/chrome/browser/prefs/pref_service_builder.h
index adcbdf06070b36a3f7c49863a2b6af9eef521f0c..262e1c2c26a2013f8e48c15659007201f6fcc28f 100644
--- a/chrome/browser/prefs/pref_service_builder.h
+++ b/chrome/browser/prefs/pref_service_builder.h
@@ -8,11 +8,13 @@
#include "base/basictypes.h"
#include "base/callback.h"
#include "base/memory/ref_counted.h"
+#include "base/memory/scoped_ptr.h"
#include "base/prefs/persistent_pref_store.h"
#include "base/prefs/pref_store.h"
+#include "chrome/browser/prefs/pref_registry.h"
class FilePath;
-class PrefServiceSimple;
+class PrefService;
namespace base {
class SequencedTaskRunner;
@@ -45,9 +47,10 @@ class PrefServiceBuilder {
PrefServiceBuilder& WithAsync(bool async);
- // Creates a PrefServiceSimple object initialized with the
- // parameters from this builder.
- virtual PrefServiceSimple* CreateSimple();
+ // Creates a PrefService object initialized with the parameters from
+ // this builder. The PrefService takes ownership of the PrefRegistry
+ // object.
+ virtual PrefService* Create(scoped_ptr<PrefRegistry> registry);
Mattias Nissler (ping if slow) 2013/01/25 14:57:11 Hm, it's a bit inconsistent to single out the regi
Jói 2013/01/29 16:10:02 Initially I did this mainly to clarify the "pass o
protected:
virtual void ResetDefaultState();

Powered by Google App Engine
This is Rietveld 408576698